Handsontable - JavaScript data grid editor. Excel-like grid editing with HTML & JavaScript
Description: Excel-like data grid with HTML & JavaScript

Star Fork
This page has been moved to http://handsontable.com/. Please update your bookmarks.

Handsontable is a minimalist Excel-like data grid editor for HTML & JavaScript

This is Handsontable , a release published on Dec 8, 2014.

The most prominent changes are:

- the removal of jQuery from dependencies and the filename,
- (but we still keep the jQuery plugin API for backward compatibility),
- dropped support for IE 8 and 9 (if it bothers you, please email us),
- more efficient row rendering algorithm.
- Basic iPad 4 support

Check out the full release notes. If you experience some rough edges, please report an issue or temporarily stick to version 0.10.5 .
Releases Wiki Options Methods Events F.A.Q. Source Issues